@@ -86,7 +86,7 @@ class Command(BaseCommand):
             reflection = Reflection(
                 pk=int(pk),
                 description=reflection_meta["description"],
-                source_table=reflection_meta["source_table"],
+                source_table_id=int(reflection_meta["source_table"]),
                 destination_database_id=int(
                     reflection_meta["destination_database"]),
                 destination_table=reflection_meta["destination_table"],
