@@ -3,21 +3,21 @@
 -- {1} $Schema$
 -- {2} $Table$
 -- {3} $Pk$
-DROP TRIGGER IF EXISTS "{1}".on_{2}_insert;
+DROP TRIGGER IF EXISTS {1}.on_{2}_insert;
 
 
-DROP TRIGGER IF EXISTS "{1}".on_{2}_update;
+DROP TRIGGER IF EXISTS {1}.on_{2}_update;
 
 
-DROP TRIGGER IF EXISTS "{1}".on_{2}_delete;
+DROP TRIGGER IF EXISTS {1}.on_{2}_delete;
 
 
 CREATE TRIGGER on_{2}_insert
 AFTER
 INSERT
-ON "{1}"."{2}" FOR EACH ROW 
+ON {1}.{2} FOR EACH ROW 
 INSERT INTO 
-      "{0}_o_{1}_o_{2}"(
+      {0}_o_{1}_o_{2}(
             c_action,
             c_record,
             c_time
@@ -32,9 +32,9 @@ INSERT INTO
 CREATE TRIGGER on_{2}_update
 AFTER
 UPDATE
-ON "{1}"."{2}" FOR EACH ROW 
+ON {1}.{2} FOR EACH ROW 
 INSERT INTO 
-      "{0}_o_{1}_o_{2}"(
+      {0}_o_{1}_o_{2}(
             c_action,
             c_record,
             c_time
@@ -49,9 +49,9 @@ INSERT INTO
 CREATE TRIGGER on_{2}_delete
 AFTER
 DELETE
-ON "{1}"."{2}" FOR EACH ROW 
+ON {1}.{2} FOR EACH ROW 
 INSERT INTO 
-      "{0}_o_{1}_o_{2}"(
+      {0}_o_{1}_o_{2}(
             c_action,
             c_record,
             c_time
